SystemOrganization addCategory: #'Seaside-Tests-Pharo-Development'!

!GRPackage class methodsFor: '*seaside-tests-pharo-development' stamp: 'lr 2/17/2010 15:14'!
seasideTestsPharoDevelopment
	^ self new
		name: 'Seaside-Tests-Pharo-Development';
		addDependency: 'Seaside-Pharo-Development';
		addDependency: 'Seaside-Tests-Development';
		url: #seasideUrl;
		yourself! !

GRObject variableSubclass: #WAExampleClass
	instanceVariableNames: 'first second'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
first
	^ first! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
first: anObject
	first := anObject! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
second
	^ second! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
second: anObject
	second := anObject! !

TestCase subclass: #WAMemoryItemTest
	instanceVariableNames: 'item'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAMemoryItemTest methodsFor: 'asserting' stamp: 'pmm 9/14/2013 11:20'!
assert: anObject equals: anOtherObject
	self
		assert: anObject = anOtherObject
		description: anObject greaseString, ' expected to be ', anOtherObject greaseString
		resumable: true! !

!WAMemoryItemTest methodsFor: 'running' stamp: 'pmm 4/2/2012 20:17'!
expectedFailures
	"'aa' sizeInMemory answers 6 but should be 8 because of alligment.
	If someone fixes this, I think #sizeInMemory would be correct."
	^ #(testSizeStringPadding)! !

!WAMemoryItemTest methodsFor: 'running' stamp: 'pmm 4/2/2012 19:52'!
setUp
	item := WAMemoryItem new! !

!WAMemoryItemTest methodsFor: 'testing' stamp: 'pmm 9/14/2013 11:21'!
testSizeOneInstanceVariable
	self assert: (item sizeOfObject: WAValueHolder new) equals: 12! !

!WAMemoryItemTest methodsFor: 'testing' stamp: 'pmm 4/2/2012 20:16'!
testSizeStringPadding
	"'aa' sizeInMemory answers 6 but should be 8 because of alligment.
	If someone fixes this, I think #sizeInMemory would be correct."
	self assert: (item sizeOfObject: 'aa') = 8! !

!WAMemoryItemTest methodsFor: 'testing' stamp: 'pmm 9/14/2013 11:21'!
testSizeVariableBytes
	self assert: (item sizeOfObject: (ByteArray new: 1)) equals: 9
	
! !

!WAMemoryItemTest methodsFor: 'testing' stamp: 'pmm 9/14/2013 11:21'!
testSizeVariableBytesLarge
	self assert: (item sizeOfObject: (ByteArray new: 256)) equals: 268! !

!WAMemoryItemTest methodsFor: 'testing' stamp: 'pmm 9/14/2013 11:21'!
testSizeVariableWords
	self assert: (item sizeOfObject: (Array new: 1)) equals: 8! !

TestCase subclass: #WANoDuplicateUuidsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WANoDuplicateUuidsTest commentStamp: 'pmm 7/23/2011 21:24' prior: 0!
I ensure that there are no two versions with the same UUID. I'm a regression test for a bug in the Pharo/Squeak/Cog VM.!

!WANoDuplicateUuidsTest methodsFor: 'tests' stamp: 'pmm 4/16/2012 17:24'!
testNoDuplicateUuids
	| workingCopies versionAncestries uuidsToVersion |
	workingCopies := WADevelopment allPackages
		collect: [ :each | WADevelopment workingCopyFor: each ].
	versionAncestries := workingCopies
		gather: [ :each | each ancestry breadthFirstAncestors ].
	uuidsToVersion := Dictionary new: versionAncestries size.
	versionAncestries do: [ :version |
		| uuid |
		uuid := version id.
		(uuidsToVersion includesKey: uuid)
			ifTrue: [ self signalFailure: version name, ' and ', (uuidsToVersion at: uuid) name , ' have duplicated UUIDs' ].
		uuidsToVersion at: uuid put: version ]! !

TestCase subclass: #WAPackagingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPackagingTest methodsFor: 'tests' stamp: 'pmm 9/12/2013 16:10'!
testPackagingValidity
	"if this test fails, it is because the current version of the Metacello configuration for Seaside3.0 doesn't match the current GRPackage specifications"

	Smalltalk
		at: #ConfigurationOfSeaside3
		ifPresent: [ :cl | 
			| gr me exceptions grease |
			gr := Dictionary new.
			GRPackage packages do: [ :pkg | gr at: pkg name put: pkg ].
			me := Dictionary new.
			cl project currentVersion packages do: [ :pkg | me at: pkg name put: pkg ].	"the following only apply when the system if fully loaded"
			false
				ifTrue: [
					exceptions := #('Sport-2' 'DynamicBindings' 'Swazoo-2' 'KomHttpServer' 'KomServices').
					me keys do: [ :key | gr at: key ifAbsent: [ self assert: (exceptions includes: key) ] ].
					exceptions := #('Grease-Core' 'Grease-Tests-Core' 'Grease-Pharo-Core' 'Grease-Tests-Pharo-Core').
					gr keys do: [ :key | me at: key ifAbsent: [ self assert: (exceptions includes: key) ] ] ].
			exceptions := #('Seaside-FileSystem' 'Seaside-Swazoo' 'Seaside-Adaptors-Comanche' 'Seaside-Tools-OmniBrowser' 'Seaside-Tests-Slime' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Pharo-Core' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Continuation' 'Seaside-Development' 'Seaside-Tests-Development').
			grease := #('Seaside-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Core' 'Seaside-Pharo-Core' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Continuation' 'Seaside-Slime' 'Seaside-GemStone-Flow' 'Seaside-GemStone-Continuation' 'Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-Slime' 'Seaside-Tests-Pharo-Email').
			me values
				do: [ :pkg | 
					| grPkg |
					grPkg := gr at: pkg name ifAbsent: [ nil ].
					grPkg notNil ifTrue: [
						| requires dependencies |
						requires := pkg requires.
						dependencies := grPkg dependencies.
						requires size ~= dependencies size
							ifTrue: [ self assert: (exceptions includes: pkg name) ]
							ifFalse: [
								dependencies do: [ :grp | 
									(requires includes: grp name)
										ifFalse: [
											(grease includes: pkg name)
												ifTrue: [ self assert: (grp name beginsWithSubCollection: 'Grease') ]
												ifFalse: [ self assert: false ] ] ] ] ] ] ]! !

TestCase subclass: #WAPharoDebuggerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPharoDebuggerTest methodsFor: 'private' stamp: 'pmm 9/17/2011 11:52'!
expectedFailures
	"The Pharo debugger API is currently broken.
	When it's fixed this test will pass again and we can add temps to the Pharo walkback again."
	^ #(testNamedTempAt)! !

!WAPharoDebuggerTest methodsFor: 'private' stamp: 'pmm 9/17/2011 11:37'!
signalInterestingError
	GRPlatform current semaphoreClass forMutualExclusion critical: [
		WAError signal: 'foo' ]! !

!WAPharoDebuggerTest methodsFor: 'tests' stamp: 'pmm 9/1/2012 16:35'!
testNamedTempAt
	"This is a test for the Pharo debugger API
	http://code.google.com/p/seaside/issues/detail?id=689"
	| frames |
	frames := OrderedCollection new.
	[ self signalInterestingError ]
		on: WAError
		do: [ :error |
			| context |
			context := error signalerContext.
			[ context isNil ] whileFalse: [
				frames add: context.
				context := context sender ] ].
	frames do: [ :each |
		1 to: each tempNames size do: [ :i |
			self shouldnt: [ each namedTempAt: i ] raise: Error ] ]! !

TestCase subclass: #WAPharoInspectorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPharoInspectorTest methodsFor: 'tests' stamp: 'jf 2/15/2010 01:06'!
testInspectorFields
	| values example fields association |
	self assert: Object new inspectorFields isEmpty.
	
	example := WAExampleClass new: 2.
	example first: 'Das Grosse Lernen'.
	example second: 'Die Analekten des Konfuzius'.
	example at: 1 put: 'Mitte und Mass'.
	example at: 2 put: 'Mengzi'.
	
	fields := example inspectorFields.
	self assert: fields size = 4.
	
	association := fields first.
	self assert: association key = #'first'.
	self assert: association value = 'Das Grosse Lernen'.
	
	association := fields second.
	self assert: association key = #'second'.
	self assert: association value = 'Die Analekten des Konfuzius'.
	
	association := fields third.
	self assert: association key = 1.
	self assert: association value = 'Mitte und Mass'.
	
	association := fields fourth.
	self assert: association key = 2.
	self assert: association value = 'Mengzi'.
	
	values := #('Das Grosse Lernen' 'Die Analekten des Konfuzius' 'Mitte und Mass' 'Mengzi').
	
	fields := values inspectorFields.
	self assert: fields size = 4.
	values keysAndValuesDo: [ :index :value |
		association := fields at: index.
		self assert: association key = index.
		self assert: association value = value ].
	
	example := Dictionary new.
	values keysAndValuesDo: [ :index :value |
		example at: index put: value ].
	
	fields := example inspectorFields.
	
	values keysAndValuesDo: [ :index :value |
		self assert: (fields at: index) value = value ]! !
